@@ -10,7 +10,7 @@ class Variable(float):
         return float.__new__(self, value)
 
     def __init__(self, value, name: str):
-        super.__init__(value)
+        float.__init__(value)
         match = U_RE.match(name)
         self.unit = (match.group("unit") or "").strip()
         self.var_name = match.group("name").strip()
